@@ -1,7 +1,7 @@
-__version__ = '4.0.11'
+__version__ = '4.1.1'
 
-from .worker.application import Application as Worker
-from .worker.blueprint import Blueprint
+from .workshop.workshop import Workshop
+from .workshop.blueprint import Blueprint
 from .trigger.trigger import Trigger
 from .share import constants
 from .share.task import Task
